"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.LaneComponentDiff = void 0;
function _componentId() {
  const data = require("@teambit/component-id");
  _componentId = function () {
    return data;
  };
  return data;
}
function _changeType() {
  const data = require("./change-type");
  _changeType = function () {
    return data;
  };
  return data;
}
class LaneComponentDiff {
  constructor(componentId, changes, upToDate, sourceHead, targetHead) {
    this.componentId = componentId;
    this.changes = changes;
    this.upToDate = upToDate;
    this.sourceHead = sourceHead;
    this.targetHead = targetHead;
  }
  get new() {
    return this.changes.includes(_changeType().ChangeType.NEW);
  }
  get changed() {
    return this.changes.length > 0 && !this.changes.includes(_changeType().ChangeType.NEW) && !this.changes.includes(_changeType().ChangeType.NONE);
  }
  get dependencyChanged() {
    return this.changes.includes(_changeType().ChangeType.DEPENDENCY);
  }
  get sourceCodeChanged() {
    return this.changes.includes(_changeType().ChangeType.SOURCE_CODE);
  }
  get changeType() {
    if (this.changes.length === 1) return this.changes[0];
    if (this.sourceCodeChanged) return _changeType().ChangeType.SOURCE_CODE;
    if (this.dependencyChanged) return _changeType().ChangeType.DEPENDENCY;
    if (this.new) return _changeType().ChangeType.NEW;
    if (this.changes.includes(_changeType().ChangeType.NONE)) return _changeType().ChangeType.NONE;
    return _changeType().ChangeType.ASPECTS;
  }
  toObject() {
    return {
      componentId: this.componentId.toString(),
      changes: this.changes,
      upToDate: this.upToDate,
      sourceHead: this.sourceHead,
      targetHead: this.targetHead
    };
  }
  static from(plainComponentDiff) {
    const id = _componentId().ComponentID.fromString(plainComponentDiff.componentId);
    return new LaneComponentDiff(id, plainComponentDiff.changes, plainComponentDiff.upToDate, plainComponentDiff.sourceHead, plainComponentDiff.targetHead);
  }
}
exports.LaneComponentDiff = LaneComponentDiff;

//# sourceMappingURL=lane-component-diff.js.map