import { ComponentID } from '@teambit/component-id';
import { LaneId } from '@teambit/lane-id';
import { LaneComponentDiff, PlainLaneComponentDiff } from './lane-component-diff';
export type PlainLaneDiff = {
    sourceLane: string;
    targetLane?: string;
    diff: PlainLaneComponentDiff[];
};
export declare class LaneDiff {
    readonly sourceLane: LaneId;
    readonly diff: LaneComponentDiff[];
    readonly targetLane?: LaneId | undefined;
    constructor(sourceLane: LaneId, diff: LaneComponentDiff[], targetLane?: LaneId | undefined);
    /**
     * count components that are up to date.
     */
    countUpToDate(): number;
    /**
     * list the components behind.
     */
    behind(): LaneComponentDiff[];
    /**
     * list the components that are up to date.
     */
    upToDate(): LaneComponentDiff[];
    /**
     * count how many components are behind their target.
     */
    countBehind(): number;
    /**
     * determines whether component is up to date.
     */
    isUpToDate(ids?: ComponentID[]): boolean;
    listOutOfDate(ids?: ComponentID[]): LaneComponentDiff[];
    get new(): LaneComponentDiff[];
    get changed(): LaneComponentDiff[];
    toObject(): PlainLaneDiff;
    static from(laneComponentDiff: PlainLaneDiff): LaneDiff;
}
