"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.LaneDiff = void 0;
function _laneId() {
  const data = require("@teambit/lane-id");
  _laneId = function () {
    return data;
  };
  return data;
}
function _laneComponentDiff() {
  const data = require("./lane-component-diff");
  _laneComponentDiff = function () {
    return data;
  };
  return data;
}
class LaneDiff {
  constructor(sourceLane, diff, targetLane) {
    this.sourceLane = sourceLane;
    this.diff = diff;
    this.targetLane = targetLane;
  }

  /**
   * count components that are up to date.
   */
  countUpToDate() {
    const upToDate = this.diff.filter(status => status.upToDate);
    return upToDate.length;
  }

  /**
   * list the components behind.
   */
  behind() {
    return this.diff.filter(status => !status.upToDate);
  }

  /**
   * list the components that are up to date.
   */
  upToDate() {
    return this.diff.filter(status => status.upToDate);
  }

  /**
   * count how many components are behind their target.
   */
  countBehind() {
    return this.behind().length;
  }

  /**
   * determines whether component is up to date.
   */
  isUpToDate(ids = []) {
    const strIds = ids?.map(id => id.toString());
    const componentDiffs = strIds.length ? this.diff.filter(componentDiff => strIds.includes(componentDiff.componentId.toString())) : this.diff;
    return componentDiffs.every(status => {
      return status.upToDate;
    });
  }
  listOutOfDate(ids) {
    const strIds = ids?.map(id => id.toString());
    const componentDiffs = strIds ? this.diff.filter(componentDiff => strIds.includes(componentDiff.componentId.toString())) : this.diff;
    return componentDiffs.filter(status => {
      return !status.upToDate;
    });
  }
  get new() {
    return this.diff.filter(diff => diff.new);
  }
  get changed() {
    return this.diff.filter(diff => diff.changed);
  }
  toObject() {
    return {
      sourceLane: this.sourceLane.toString(),
      targetLane: this.targetLane?.toString(),
      diff: this.diff.map(componentDiff => componentDiff.toObject())
    };
  }
  static from(laneComponentDiff) {
    const laneComponentDiffList = laneComponentDiff.diff.map(componentDiff => _laneComponentDiff().LaneComponentDiff.from(componentDiff));
    return new LaneDiff(_laneId().LaneId.parse(laneComponentDiff.sourceLane), laneComponentDiffList, laneComponentDiff?.targetLane ? _laneId().LaneId.parse(laneComponentDiff.targetLane) : undefined);
  }
}
exports.LaneDiff = LaneDiff;

//# sourceMappingURL=lane-diff.js.map